@@ -35,8 +35,6 @@ UNPACK_DIR = None
 RAW_UNPACK_DIR = None
 TMP_DIR = None
 VALID_SYSCALL = r'^[a-z0-9_]{2,64}$'
-# This needs to match up with snapcraft
-MKSQUASHFS_OPTS = ['-noappend', '-comp', 'xz', '-all-root', '-no-xattrs']
 # There are quite a few kernel interfaces that can cause problems with
 # long profile names. These are outlined in
 # https://launchpad.net/bugs/1499544. The big issue is that the audit
@@ -50,6 +48,8 @@ MKSQUASHFS_OPTS = ['-noappend', '-comp', 'xz', '-all-root', '-no-xattrs']
 # under LXC
 AA_PROFILE_NAME_MAXLEN = 230  # 245 minus a bit for child profiles
 AA_PROFILE_NAME_ADVLEN = 100
+# Store enforces this length for snap v2
+STORE_PKGNAME_SNAPV2_MAXLEN = 40
 
 
 def cleanup_unpack():
@@ -88,6 +88,9 @@ class Review(object):
         'application/x-executable; charset=binary',
         'application/x-sharedlib; charset=binary',
         'application/x-object; charset=binary',
+        'application/x-executable',
+        'application/x-sharedlib',
+        'application/x-object',
     ]
 
     def __init__(self, fn, review_type, overrides=None):
@@ -606,7 +609,7 @@ def detect_package(fn, dir=None):
 
 def find_external_symlinks(unpack_dir, pkg_files, pkgname):
     '''Check if symlinks in the package go out to the system.'''
-    common = '(-[0-9.]+)?\.so(\.[0-9.]+)?'
+    common = r'(-[0-9.]+)?\.so(\.[0-9.]+)?'
     libc6_libs = ['ld-*.so',
                   'libanl',
                   'libBrokenLocale',
@@ -637,6 +640,7 @@ def find_external_symlinks(unpack_dir, pkg_files, pkgname):
         libc6_pats.append(re.compile(r'%s%s' % (lib, common)))
     libc6_pats.append(re.compile(r'ld-*.so$'))
     libc6_pats.append(re.compile(r'ld-linux-.*.so\.[0-9.]+$'))
+    libc6_pats.append(re.compile(r'ld64.so\.[0-9.]+$'))  # ppc64el
 
     def _in_patterns(pats, f):
         for pat in pats:
