@@ -72,8 +72,9 @@ class ClickReviewDesktop(ClickReview):
                                'webapp-container',
                                'ubuntu-html5-app-launcher',
                                ]
-        self.deprecated_execs = ['cordova-ubuntu-2.8',
-                                 ]
+        self.deprecated_execs = ['cordova-ubuntu-2.8']
+        self.allowed_extension_execs = ['.py']
+
         # TODO: the desktop hook will actually handle this correctly
         self.blacklisted_keys = ['Path']
 
@@ -225,14 +226,20 @@ class ClickReviewDesktop(ClickReview):
                         'what-does-desktop-exec-mean/417382')
             elif de.getExec().split()[0] not in self.expected_execs:
                 if self.pkg_arch[0] == "all":  # interpreted file
-                    template = "found %s Exec with architecture '%s': %s"
-                    if de.getExec().split()[0] not in self.deprecated_execs:
-                        verb = 'unexpected'
+                    check = os.path.splitext(de.getExec().split()[0])
+
+                    if check[1] in self.allowed_extension_execs:
+                        s = 'ALlowed exec with %s extension' % check[1]
+                        t = 'info'
                     else:
-                        verb = 'deprecated'
-                    s = template % \
-                        (verb, self.pkg_arch[0], de.getExec().split()[0])
-                    t = 'warn'
+                        template = "found %s Exec with architecture '%s': %s"
+                        if de.getExec().split()[0] not in self.deprecated_execs:
+                            verb = 'unexpected'
+                        else:
+                            verb = 'deprecated'
+                        s = template % \
+                            (verb, self.pkg_arch[0], de.getExec().split()[0])
+                        t = 'warn'
                 else:                        # compiled
                     # TODO: this can be a lot smarter
                     s = "Non-standard Exec with architecture " + \
