@@ -306,24 +306,27 @@ class ClickReviewAccounts(ClickReview):
             self._add_result(t, n, s)
 
             t = 'info'
-            n = self._get_check_name('%s_services' % account_type, app=app)
+            n = self._get_check_name('%s_services_service-types' % account_type, app=app)
             s = "OK"
-            if self.accounts[app][account_type].find("services") is None:
+            stanzas = [
+                (parent_tag, child_tag) for (parent_tag, child_tag) in
+                (("services", "service"), ("service-types", "service-type"))
+                if self.accounts[app][account_type].find(parent_tag) is not None
+            ]
+            if len(stanzas) == 0:
                 t = 'error'
-                s = "Could not find '<services>' tag"
+                s = "Could neither find '<services>' nor '<service-types>' tag"
             self._add_result(t, n, s)
 
-            if t == 'error':
-                continue
-
-            t = 'info'
-            n = self._get_check_name('%s_service' % account_type, app=app)
-            s = "OK"
-            if self.accounts[app][account_type].find("./services/service") \
-               is None:
-                t = 'error'
-                s = "Could not find '<service>' tag under <services>"
-            self._add_result(t, n, s)
+            for (parent_tag, child_tag) in stanzas:
+                t = 'info'
+                n = self._get_check_name('%s_%s' % (account_type, child_tag), app=app)
+                s = "OK"
+                if self.accounts[app][account_type].find(
+                        "./%s/%s" % (parent_tag, child_tag)) is None:
+                    t = 'error'
+                    s = "Could not find '<%s>' tag under <%s>" % (child_tag, parent_tag)
+                self._add_result(t, n, s)
 
     def check_service(self):
         '''Check service'''
