@@ -22,7 +22,7 @@ from clickreviews.common import (
 )
 from clickreviews.cr_common import ClickReview, error, open_file_read
 import clickreviews.cr_common as cr_common
-import clickreviews.apparmor_policy as apparmor_policy
+from clickreviews.apparmor import APPARMOR_POLICIES
 import copy
 import json
 import os
@@ -38,7 +38,7 @@ class ClickReviewSecurity(ClickReview):
         peer_hooks[my_hook]['allowed'] = ClickReview.app_allowed_peer_hooks + \
             ClickReview.scope_allowed_peer_hooks + \
             ClickReview.service_allowed_peer_hooks + \
-            ['pay-ui']
+            ['pay-ui', 'language-packs']
         peer_hooks[my_hook]['required'] = []
 
         my_hook2 = 'apparmor-profile'
@@ -54,16 +54,7 @@ class ClickReviewSecurity(ClickReview):
         if not self.is_click and not self.is_snap1:
             return
 
-        # If local_copy is None, then this will check the server to see if
-        # we are up to date. However, if we are working within the development
-        # tree, use it unconditionally.
-        local_copy = None
-        branch_fn = os.path.join(os.path.dirname(__file__),
-                                 '../data/apparmor-easyprof-ubuntu.json')
-        if os.path.exists(branch_fn):
-            local_copy = branch_fn
-        p = apparmor_policy.ApparmorPolicy(local_copy)
-        self.aa_policy = p.policy
+        self.aa_policy = APPARMOR_POLICIES
 
         self.all_fields = ['abstractions',
                            'author',
@@ -132,10 +123,16 @@ class ClickReviewSecurity(ClickReview):
             'ubuntu-sdk-15.04': {
                 'policy_version': 1.3,
             },
+            'ubuntu-sdk-16.04': {
+                'policy_version': 16.04,
+            },
+            'ubuntu-sdk-20.04': {
+                'policy_version': 20.04,
+            },
             'ubuntu-core-15.04': {
                 'policy_vendor': 'ubuntu-core',
                 'policy_version': 15.04,
-            },
+            }
         }
         framework_overrides = self.overrides.get('framework', {})
         self._override_framework_policies(framework_overrides)
@@ -190,26 +187,27 @@ class ClickReviewSecurity(ClickReview):
         else:
             self.security_manifests = dict()
             self.security_apps = []
-            for app in self.manifest['hooks']:
-                if 'apparmor' not in self.manifest['hooks'][app]:
+            hooks = self.manifest['hooks']
+            for app in hooks:
+                if 'apparmor' not in hooks[app]:
                     #  msg("Skipped missing apparmor hook for '%s'" % app)
                     continue
-                if not isinstance(self.manifest['hooks'][app]['apparmor'], str):
-                    error("manifest malformed: hooks/%s/apparmor is not str" % app)
-                rel_fn = self.manifest['hooks'][app]['apparmor']
+                if not isinstance(hooks[app]['apparmor'], str):
+                    error("manifest malformed: hooks/%s/apparmor "
+                          "is not str" % app)
+                rel_fn = hooks[app]['apparmor']
                 self.security_manifests[rel_fn] = \
                     self._extract_security_manifest(app)
                 self.security_apps.append(app)
 
-            for app in self.manifest['hooks']:
-                if 'apparmor-profile' not in self.manifest['hooks'][app]:
+            for app in hooks:
+                if 'apparmor-profile' not in hooks[app]:
                     #  msg("Skipped missing apparmor hook for '%s'" % app)
                     continue
-                if not isinstance(self.manifest['hooks'][app]['apparmor-profile'],
-                                  str):
-                    error("manifest malformed: hooks/%s/apparmor-profile is not "
-                          "str" % app)
-                rel_fn = self.manifest['hooks'][app]['apparmor-profile']
+                if not isinstance(hooks[app]['apparmor-profile'], str):
+                    error("manifest malformed: hooks/%s/apparmor-profile "
+                          "is not str" % app)
+                rel_fn = hooks[app]['apparmor-profile']
                 self.security_profiles[rel_fn] = \
                     self._extract_security_profile(app)
                 self.security_apps_profiles.append(app)
@@ -341,7 +339,8 @@ class ClickReviewSecurity(ClickReview):
             self._add_result(t, n, s)
 
             t = 'info'
-            n = self._get_check_name('policy_vendor_matches_framework', extra=f)
+            n = self._get_check_name('policy_vendor_matches_framework',
+                                     extra=f)
             s = "OK"
             if 'policy_vendor' in m:  # policy_vendor is optional
                 found_major = False
@@ -409,7 +408,8 @@ class ClickReviewSecurity(ClickReview):
             self._add_result(t, n, s, link)
 
             t = 'info'
-            n = self._get_check_name('policy_version_matches_framework', extra=f)
+            n = self._get_check_name('policy_version_matches_framework',
+                                     extra=f)
             s = "OK"
             found_major = False
             for name, data in self.major_framework_policy.items():
@@ -687,7 +687,8 @@ class ClickReviewSecurity(ClickReview):
                 vendor = m['policy_vendor']
             version = str(m['policy_version'])
 
-            policy_groups = self._get_policy_groups(version=version, vendor=vendor)
+            policy_groups = self._get_policy_groups(version=version,
+                                                    vendor=vendor)
             if len(policy_groups) < 1:
                 t = 'error'
                 s = 'could not find policy groups'
@@ -697,7 +698,8 @@ class ClickReviewSecurity(ClickReview):
 
             # Check for duplicates
             t = 'info'
-            n = self._get_check_name('policy_groups_duplicates', app=app, extra=f)
+            n = self._get_check_name('policy_groups_duplicates',
+                                     app=app, extra=f)
             s = 'OK'
             tmp = []
             for p in m['policy_groups']:
@@ -724,7 +726,8 @@ class ClickReviewSecurity(ClickReview):
             # If we got here, we can see if valid policy groups were specified
             for i in m['policy_groups']:
                 t = 'info'
-                n = self._get_check_name('policy_groups_valid', app=app, extra=i)
+                n = self._get_check_name('policy_groups_valid',
+                                         app=app, extra=i)
                 s = 'OK'
 
                 # SDK will leave and empty policy group, report but don't
@@ -787,7 +790,8 @@ class ClickReviewSecurity(ClickReview):
                         t = 'error'
                         s = "policy group '%s' has " % i + \
                             "unknown type '%s'" % (aa_type)
-                    self._add_result(t, n, s, link, manual_review=manual_review)
+                    self._add_result(t, n, s, link,
+                                     manual_review=manual_review)
 
     def check_ignored(self):
         '''Check ignored fields'''
@@ -821,6 +825,7 @@ class ClickReviewSecurity(ClickReview):
             t = 'info'
             n = self._get_check_name('redflag_fields', extra=f)
             s = "OK"
+            mr = False
             found = []
             for i in self.redflag_fields:
                 if i in m:
@@ -831,9 +836,11 @@ class ClickReviewSecurity(ClickReview):
 
             if len(found) > 0:
                 t = 'error'
-                s = "found redflagged fields (needs human review): %s" % \
+                s = "(NEEDS REVIEW) found redflagged fields: %s" % \
                     ", ".join(found)
-            self._add_result(t, n, s)
+                mr = True
+
+            self._add_result(t, n, s, manual_review=mr)
 
     def check_required(self):
         '''Check required fields'''
@@ -1215,12 +1222,12 @@ class ClickReviewSecurity(ClickReview):
                 else:
                     if 'apparmor' not in item['security-override']:
                         t = 'error'
-                        s = "'apparmor' not specified in 'security-override' " + \
-                            "for '%s'" % app
+                        s = ("'apparmor' not specified in 'security-override' "
+                             "for '%s'" % app)
                     elif 'seccomp' not in item['security-override']:
                         t = 'error'
-                        s = "'seccomp' not specified in 'security-override' " + \
-                            "for '%s'" % app
+                        s = ("'seccomp' not specified in 'security-override' "
+                             "for '%s'" % app)
 
                 self._add_result(t, n, s)
 
@@ -1265,7 +1272,8 @@ class ClickReviewSecurity(ClickReview):
                     t = 'error'
                     n = self._get_check_name('yaml_policy_present')
                     s = "(NEEDS REVIEW) 'security-policy' not allowed"
-                    link = 'https://developer.ubuntu.com/en/snappy/guides/security-policy/'
+                    link = ('https://developer.ubuntu.com/en/snappy/guides/'
+                            'security-policy/')
                     m = True
                     self._add_result(t, n, s, link=link, manual_review=m)
 
@@ -1274,7 +1282,8 @@ class ClickReviewSecurity(ClickReview):
         if not self.is_click and not self.is_snap1:
             return
 
-        if not self.is_snap1 or self.pkg_yaml['type'] in self.sec_skipped_types:
+        if not self.is_snap1 or \
+                self.pkg_yaml['type'] in self.sec_skipped_types:
             return
 
         for exe_t in ['services', 'binaries']:
@@ -1314,7 +1323,8 @@ class ClickReviewSecurity(ClickReview):
         if not self.is_click and not self.is_snap1:
             return
 
-        if not self.is_snap1 or self.pkg_yaml['type'] in self.sec_skipped_types:
+        if not self.is_snap1 or \
+                self.pkg_yaml['type'] in self.sec_skipped_types:
             return
 
         for exe_t in ['services', 'binaries']:
@@ -1350,7 +1360,8 @@ class ClickReviewSecurity(ClickReview):
 
                 if self.is_snap1:
                     t = 'info'
-                    n = self._get_check_name('yaml_security-template_in_manifest', app=app)
+                    n = self._get_check_name('yaml_security-'
+                                             'template_in_manifest', app=app)
                     s = "OK"
                     if app not in self.manifest['hooks']:
                         t = 'error'
@@ -1360,7 +1371,8 @@ class ClickReviewSecurity(ClickReview):
                     elif 'apparmor' not in self.manifest['hooks'][app] and \
                          'apparmor-profile' not in self.manifest['hooks'][app]:
                         t = 'error'
-                        s = "'apparmor' not found in click manifest for '%s'" % app
+                        s = ("'apparmor' not found in click manifest "
+                             "for '%s'" % app)
                         self._add_result(t, n, s)
                         continue
 
@@ -1371,7 +1383,8 @@ class ClickReviewSecurity(ClickReview):
         if not self.is_click and not self.is_snap1:
             return
 
-        if not self.is_snap1 or self.pkg_yaml['type'] in self.sec_skipped_types:
+        if not self.is_snap1 or \
+                self.pkg_yaml['type'] in self.sec_skipped_types:
             return
 
         for exe_t in ['services', 'binaries']:
@@ -1417,7 +1430,8 @@ class ClickReviewSecurity(ClickReview):
                     elif 'apparmor' not in self.manifest['hooks'][app] and \
                          'apparmor-profile' not in self.manifest['hooks'][app]:
                         t = 'error'
-                        s = "'apparmor' not found in click manifest for '%s'" % app
+                        s = ("'apparmor' not found in click manifest "
+                             "for '%s'" % app)
                         self._add_result(t, n, s)
                         continue
 
