@@ -430,6 +430,8 @@ class TestClickReview(TestCase):
         self.test_manifest["hooks"][self.default_appname]["urls"] = \
             "%s.url-dispatcher" % self.default_appname
         self._update_test_manifest()
+        self.test_manifest["migrations"] = dict()
+        self.test_manifest["migrations"]["old-name"] = "old-test-app"
 
         self.test_pkg_yaml = dict()
         self.set_test_pkg_yaml("name", self.test_control['Package'])
