@@ -77,6 +77,26 @@ class TestClickReviewDesktop(cr_tests.TestClickReview):
         expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
+    def test_check_desktop_file_has_allowed_extension(self):
+        '''Test check_desktop_exec() - Exec has allowed extension'''
+        c = ClickReviewDesktop(self.test_name)
+        self.set_test_desktop(self.default_appname,
+                              "Exec", "some-script.py")
+        c.check_desktop_exec()
+        r = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_desktop_file_does_not_has_allowed_extension(self):
+        '''Test check_desktop_exec() - Exec does not have allowed extension'''
+        c = ClickReviewDesktop(self.test_name)
+        self.set_test_desktop(self.default_appname,
+                              "Exec", "some-script.js")
+        c.check_desktop_exec()
+        r = c.click_report
+        expected_counts = {'info': 0, 'warn': 1, 'error': 0}
+        self.check_results(r, expected_counts)
+
     def test_check_desktop_latest_version(self):
         '''Test check_desktop_version()'''
         c = ClickReviewDesktop(self.test_name)
