@@ -591,6 +591,17 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
+    def test_check_migrations(self):
+        '''Test check_migrations() present'''
+        self.set_test_manifest("migrations", {"old-name": "old-test-app"})
+        c = ClickReviewLint(self.test_name)
+        c.check_migrations()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+        name = c._get_check_name('migrations_present')
+        self.check_manual_review(r, name)
+
     def test_check_framework(self):
         '''Test check_framework()'''
         self.patch_frameworks()
