@@ -271,6 +271,36 @@ class TestClickReviewAccounts(cr_tests.TestClickReview):
         expected_counts = {'info': 4, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
+    def test_check_application_with_service_types(self):
+        '''Test check_application() with both <services> and <service-types>'''
+        xml = self._stub_application()
+        service_types = etree.SubElement(xml, "service-types")
+        elem = etree.SubElement(service_types, "service-type")
+        desc = etree.SubElement(elem, "description")
+        desc.text = "elem description"
+        # print(etree.tostring(xml))
+        self.set_test_account(self.default_appname, "account-application", xml)
+        c = ClickReviewAccounts(self.test_name)
+        c.check_application()
+        r = c.click_report
+        expected_counts = {'info': 5, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_application_with_service_types_only(self):
+        '''Test check_application() with <service-types> but not <services>'''
+        xml = self._stub_application(do_subtree=False)
+        service_types = etree.SubElement(xml, "service-types")
+        elem = etree.SubElement(service_types, "service-type")
+        desc = etree.SubElement(elem, "description")
+        desc.text = "elem description"
+        # print(etree.tostring(xml))
+        self.set_test_account(self.default_appname, "account-application", xml)
+        c = ClickReviewAccounts(self.test_name)
+        c.check_application()
+        r = c.click_report
+        expected_counts = {'info': 4, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
     def test_check_application_not_specified(self):
         '''Test check_application() - not specified'''
         c = ClickReviewAccounts(self.test_name)
